@@ -41,8 +41,8 @@ prForestPlotPrep <- function(regressions,
                                              TRUE ~ rowname),
                          is_summary = FALSE,
                          across(.cols = c(estimate, starts_with("conf.")), 
-                                txtRound, 
-                                digits = digits, .names = "txt_{.col}"),
+                                .fns = \(x) txtRound(x, digits = digits),
+                                .names = "txt_{.col}"),
                          est_txt = if_else(row_number() == 1,
                                            estimate.txt,
                                            txt_estimate),
